==> mule-standalone-3.1.0.zip: org/mule/routing/correlation/ResequenceMessagesCorrelatorCallback.java <==
/*
 * $Id: ResequenceMessagesCorrelatorCallback.java 20321 2010-11-24 15:21:24Z dfeist $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.routing.correlation;

import org.mule.DefaultMuleEvent;
import org.mule.DefaultMuleMessage;
import org.mule.api.MuleContext;
import org.mule.api.MuleEvent;
import org.mule.routing.AggregationException;
import org.mule.routing.EventGroup;

import java.util.Arrays;
import java.util.Comparator;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * A Correlator that correlates messages based on Mule correlation settings
 * Note that the {@link #aggregateEvents(org.mule.routing.EventGroup)} method only resequences the events and
 * returns an MuleEvent[] wrapped in a MuleMessage impl.  This means that this callback can ONLY be used with a
 * {@link org.mule.routing.inbound.CorrelationEventResequencer}
 */
public class ResequenceMessagesCorrelatorCallback extends CollectionCorrelatorCallback
{
    /**
     * logger used by this class
     */
    protected transient final Log logger = LogFactory.getLog(ResequenceMessagesCorrelatorCallback.class);

    protected Comparator eventComparator;
    protected MuleContext muleContext;

    public ResequenceMessagesCorrelatorCallback(Comparator eventComparator, MuleContext muleContext)
    {
        super(muleContext);
        this.eventComparator = eventComparator;
        this.muleContext = muleContext;
    }

    /**
     * This method is invoked if the shouldAggregate method is called and returns
     * true. Once this method returns an aggregated message, the event group is
     * removed from the router.
     *
     * @param events the event group for this request
     * @return an aggregated message
     * @throws org.mule.routing.AggregationException
     *          if the aggregation fails. in this scenario the
     *          whole event group is removed and passed to the exception handler
     *          for this componenet
     */
    public MuleEvent aggregateEvents(EventGroup events) throws AggregationException
    {
        MuleEvent[] results = (events == null) ? new MuleEvent[0] : events.toArray();
        Arrays.sort(results, eventComparator);
        //This is a bit of a hack since we return a collection of events on one message
        return new DefaultMuleEvent(new DefaultMuleMessage(results, muleContext), results[0]);
    }

}

==> mule-standalone-3.1.2.zip: org/mule/routing/correlation/ResequenceMessagesCorrelatorCallback.java <==
/*
 * $Id: ResequenceMessagesCorrelatorCallback.java 20814 2010-12-21 12:24:23Z dirk.olmes $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.routing.correlation;

import org.mule.DefaultMuleEvent;
import org.mule.DefaultMuleMessage;
import org.mule.api.MuleContext;
import org.mule.api.MuleEvent;
import org.mule.routing.AggregationException;
import org.mule.routing.EventGroup;
import org.mule.routing.Resequencer;

import java.util.Arrays;
import java.util.Comparator;

/**
 * A Correlator that correlates messages based on Mule correlation settings
 * Note that the {@link #aggregateEvents(org.mule.routing.EventGroup)} method only resequences the events and
 * returns an MuleEvent[] wrapped in a MuleMessage impl.  This means that this callback can ONLY be used with a
 * {@link Resequencer}
 */
public class ResequenceMessagesCorrelatorCallback extends CollectionCorrelatorCallback
{
    protected Comparator eventComparator;
    protected MuleContext muleContext;

    public ResequenceMessagesCorrelatorCallback(Comparator eventComparator, MuleContext muleContext)
    {
        super(muleContext);
        this.eventComparator = eventComparator;
        this.muleContext = muleContext;
    }

    /**
     * This method is invoked if the shouldAggregate method is called and returns
     * true. Once this method returns an aggregated message, the event group is
     * removed from the router.
     *
     * @param events the event group for this request
     * @return an aggregated message
     * @throws org.mule.routing.AggregationException if the aggregation fails. in
     *             this scenario the whole event group is removed and passed to the
     *             exception handler for this componenet
     */
    @Override
    public MuleEvent aggregateEvents(EventGroup events) throws AggregationException
    {
        MuleEvent[] results = (events == null) ? new MuleEvent[0] : events.toArray();
        Arrays.sort(results, eventComparator);
        //This is a bit of a hack since we return a collection of events on one message
        return new DefaultMuleEvent(new DefaultMuleMessage(results, muleContext), results[0]);
    }

}
